@@ -30,8 +30,8 @@ assess_missing_data_pca <- function(vcfR,
   PC2<- NULL
   pop<- NULL
 
-  #if vcfR is not class vcfR, fail gracefully
-  if (class(vcfR) != "vcfR"){
+  #if vcfR fails check for class == vcfR, fail gracefully
+  if (!inherits(vcfR, what = "vcfR")){
     stop("specified vcfR object must be of class 'vcfR'")
   }
 
@@ -41,7 +41,7 @@ assess_missing_data_pca <- function(vcfR,
   }
 
   #if popmap not formatted correctly, fail gracefully
-  if (class(popmap) != "data.frame"){
+  if (!inherits(popmap, what = "data.frame")){
     stop("popmap must be of class 'data.frame'")
   }
 
@@ -66,12 +66,21 @@ assess_missing_data_pca <- function(vcfR,
   }
 
   #this PCA cannot tolerate invariant SNP positions, so check for invariant SNP positions
+
   #convert vcfR to matrix and make numeric
   gt.matrix<-vcfR::extract.gt(vcfR)
+  missingness.og<-sum(is.na(gt.matrix)) #store missingness
   gt.matrix[gt.matrix == "0/0"]<-0
   gt.matrix[gt.matrix == "0/1"]<-1
+  gt.matrix[gt.matrix == "1/0"]<-1
   gt.matrix[gt.matrix == "1/1"]<-2
   class(gt.matrix) <- "numeric"
+  missingness.new<-sum(is.na(gt.matrix)) #store missingness after the conversion
+
+  #if unrecognized genotype values were present throw an error
+  if (missingness.og != missingness.new){
+    stop("Unrecognized genotype values in input vcf. Only allowed genotype inputs are '0/0','0/1','1/0','1/1'.Use 'table(vcfR@gt)' to see your input genotypes.")
+  }
 
   #calc sfs
   sfs<-rowSums(gt.matrix, na.rm = TRUE)
@@ -132,7 +141,7 @@ assess_missing_data_pca <- function(vcfR,
       pam.clust<-cluster::pam(pca.scores, pam.df$n.groups[pam.df$likelihood==max(pam.df$likelihood)])
 
       #match order for pop from popmap into this df
-      pca.scores$pop<-popmap$pop[order(popmap$id == colnames(vcfR@gt)[-1])]
+      pca.scores$pop<-popmap$pop[order(match(popmap$id,colnames(vcfR@gt)[-1]))]
       pca.scores$pam.clust<-pam.clust$clustering
       #add missingness to df
       #calculate missingness by individual
@@ -234,7 +243,7 @@ assess_missing_data_pca <- function(vcfR,
         pam.clust<-cluster::pam(pca.scores, pam.df$n.groups[pam.df$likelihood==max(pam.df$likelihood)])
 
         #match order for pop from popmap into this df
-        pca.scores$pop<-popmap$pop[order(popmap$id == colnames(vcfR@gt)[-1])]
+        pca.scores$pop<-popmap$pop[order(match(popmap$id,colnames(vcfR@gt)[-1]))]
         pca.scores$pam.clust<-pam.clust$clustering
 
         #add missingness to df
@@ -331,7 +340,7 @@ assess_missing_data_pca <- function(vcfR,
       #pca.scores$pop<-popmap$pop
 
       #match order for pop from popmap into this df
-      pca.scores$pop<-popmap$pop[order(popmap$id == colnames(vcfR@gt)[-1])]
+      pca.scores$pop<-popmap$pop[order(match(popmap$id,colnames(vcfR@gt)[-1]))]
       #add missingness to df
       #calculate missingness by individual
       miss<-colSums(is.na(vcfR@gt))/nrow(vcfR@gt)
@@ -410,7 +419,7 @@ assess_missing_data_pca <- function(vcfR,
         pca.scores<-as.data.frame(pca$scores)
 
         #match order for pop from popmap into this df
-        pca.scores$pop<-popmap$pop[order(popmap$id == colnames(vcfR@gt)[-1])]
+        pca.scores$pop<-popmap$pop[order(match(popmap$id,colnames(vcfR@gt)[-1]))]
         #add missingness to df
         #calculate missingness by individual
         miss<-colSums(is.na(vcfR.filt@gt))/nrow(vcfR.filt@gt)
